==> pegasus-merchandise-api-1.4.9-sources.jar: com/thebeastshop/pegasus/merchandise/vo/OpProdDynmcontColumnVO.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.List;

/**
 * @author huan.xiong
 * @version $Id: OpProdDynmcontColumnVO.java, v 0.1 2017-09-07 10:56
 */
public class OpProdDynmcontColumnVO implements Serializable {
    /**
     * ID
     */
    private Long id;
    
    /**
     * 标题
     */
    private String titleCn;
    private String titleEn;
    /**
     * 是否必填(0-是 1-否)
     */
    private Integer isRequired;
    /**
     * 是否展开(0-是 1-否)
     */
    private Integer isOpen;
    /**
     * 排序
     */
    private Integer sort;
    /**
     * 栏目样式
     */
    private String demo;
    /**
     * 是否有效(0-有效 1-无效)
     */
    private Integer isValid;
    
    private String oldContent;//老版本内容
    
    /**
     * 动态内容详情LIST
     */
    private List<OpProdDynmDetailsVO> opProdDynmDetailsVOList;
    
    /**
     * 动态内容表格详情LIST
     */
    private List<OpProdDynmDetailsVO> dynmExcelList;

    public List<OpProdDynmDetailsVO> getDynmExcelList() {
		return dynmExcelList;
	}

	public void setDynmExcelList(List<OpProdDynmDetailsVO> dynmExcelList) {
		this.dynmExcelList = dynmExcelList;
	}

	public List<OpProdDynmDetailsVO> getOpProdDynmDetailsVOList() {
		return opProdDynmDetailsVOList;
	}

	public void setOpProdDynmDetailsVOList(List<OpProdDynmDetailsVO> opProdDynmDetailsVOList) {
		this.opProdDynmDetailsVOList = opProdDynmDetailsVOList;
	}

	public String getOldContent() {
		return oldContent;
	}

	public void setOldContent(String oldContent) {
		this.oldContent = oldContent;
	}

	public String getTitleEn() {
        return titleEn;
    }

    public void setTitleEn(String titleEn) {
        this.titleEn = titleEn;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }


    public String getTitleCn() {
        return titleCn;
    }

    public void setTitleCn(String titleCn) {
        this.titleCn = titleCn;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

	public Integer getIsRequired() {
		return isRequired;
	}

	public void setIsRequired(Integer isRequired) {
		this.isRequired = isRequired;
	}

	public Integer getIsOpen() {
		return isOpen;
	}

	public void setIsOpen(Integer isOpen) {
		this.isOpen = isOpen;
	}

	public String getDemo() {
		return demo;
	}

	public void setDemo(String demo) {
		this.demo = demo;
	}

	public Integer getIsValid() {
		return isValid;
	}

	public void setIsValid(Integer isValid) {
		this.isValid = isValid;
	}
}

==> pegasus-merchandise-api-1009487-20250912.055113-1-sources.jar: com/thebeastshop/pegasus/merchandise/vo/OpProdDynmcontColumnVO.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.List;

/**
 * @author huan.xiong
 * @version $Id: OpProdDynmcontColumnVO.java, v 0.1 2017-09-07 10:56
 */
public class OpProdDynmcontColumnVO implements Serializable {
    /**
     * ID
     */
    private Long id;
    
    /**
     * 标题
     */
    private String titleCn;
    private String titleEn;
    /**
     * 是否必填(0-是 1-否)
     */
    private Integer isRequired;
    /**
     * 是否展开(0-是 1-否)
     */
    private Integer isOpen;
    /**
     * 排序
     */
    private Integer sort;
    /**
     * 栏目样式
     */
    private String demo;
    /**
     * 是否有效(0-有效 1-无效)
     */
    private Integer isValid;
    
    private String oldContent;//老版本内容



    private String clearGap;

    
    /**
     * 动态内容详情LIST
     */
    private List<OpProdDynmDetailsVO> opProdDynmDetailsVOList;
    
    /**
     * 动态内容表格详情LIST
     */
    private List<OpProdDynmDetailsVO> dynmExcelList;

    public List<OpProdDynmDetailsVO> getDynmExcelList() {
		return dynmExcelList;
	}

	public void setDynmExcelList(List<OpProdDynmDetailsVO> dynmExcelList) {
		this.dynmExcelList = dynmExcelList;
	}

	public List<OpProdDynmDetailsVO> getOpProdDynmDetailsVOList() {
		return opProdDynmDetailsVOList;
	}

	public void setOpProdDynmDetailsVOList(List<OpProdDynmDetailsVO> opProdDynmDetailsVOList) {
		this.opProdDynmDetailsVOList = opProdDynmDetailsVOList;
	}

	public String getOldContent() {
		return oldContent;
	}

	public void setOldContent(String oldContent) {
		this.oldContent = oldContent;
	}

	public String getTitleEn() {
        return titleEn;
    }

    public void setTitleEn(String titleEn) {
        this.titleEn = titleEn;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }


    public String getTitleCn() {
        return titleCn;
    }

    public void setTitleCn(String titleCn) {
        this.titleCn = titleCn;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

	public Integer getIsRequired() {
		return isRequired;
	}

	public void setIsRequired(Integer isRequired) {
		this.isRequired = isRequired;
	}

	public Integer getIsOpen() {
		return isOpen;
	}

	public void setIsOpen(Integer isOpen) {
		this.isOpen = isOpen;
	}

	public String getDemo() {
		return demo;
	}

	public void setDemo(String demo) {
		this.demo = demo;
	}

	public Integer getIsValid() {
		return isValid;
	}

	public void setIsValid(Integer isValid) {
		this.isValid = isValid;
	}

    public String getClearGap() {
        return clearGap;
    }

    public void setClearGap(String clearGap) {
        this.clearGap = clearGap;
    }
}
